import * as _codemirror_state from '@codemirror/state';
import { StateField, Extension } from '@codemirror/state';
import { MarkdownConfig } from '@lezer/markdown';
import { ViewPlugin, DecorationSet, EditorView, ViewUpdate } from '@codemirror/view';

interface HeadingSlug {
    slug: string;
    pos: number;
}
/**
 * A plugin that stores the calculated slugs of the document headings in the
 * editor state. These can be useful when resolving links to headings inside
 * the document.
 */
declare const headingSlugField: StateField<HeadingSlug[]>;

/**
 * CodeMirror plugin to style Markdown blockquotes.
 */
declare function blockquote(): _codemirror_state.Extension[];

/**
 * CodeMirror extension to style code blocks.
 */
declare const codeblock: () => _codemirror_state.Extension[];

/**
 * Lezer Markdown extension for YAML frontmatter support. This includes support
 * for parsing, syntax highlighting and folding.
 */
declare const frontmatter: MarkdownConfig;

/**
 * CodeMirror plugin to enchance Markdown headings.
 */
declare const headings: () => _codemirror_state.Extension[];

declare class HideMarkPlugin {
    decorations: DecorationSet;
    constructor(view: EditorView);
    update(update: ViewUpdate): void;
    compute(view: EditorView): DecorationSet;
}
/**
 * CodeMirror plugin to hide Markdown decoration marks.
 */
declare const hideMarks: () => ViewPlugin<HideMarkPlugin>[];

/**
 * CodeMirror plugin to enchance Markdown links.
 */
declare const links: () => _codemirror_state.Extension[];

/**
 * CodeMirror plugin to add make Markdown lists look better.
 * This includes:
 * - Custom list mark
 * - Checkbox for task lists
 */
declare const lists: () => _codemirror_state.Extension[];

declare const basicSetup: Extension;

export { basicSetup, blockquote, codeblock, frontmatter, headingSlugField, headings, hideMarks, links, lists };
